Class: Google::Apis::VmmigrationV1alpha1::CutoverJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

CutoverJob message describes a cutover of a migrating VM. The CutoverJob is the operation of shutting down the VM, creating a snapshot and cloning the VM using the replicated snapshot.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CutoverJob

Returns a new instance of CutoverJob.



1790
1791
1792
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1790

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compute_engine_disks_target_detailsGoogle::Apis::VmmigrationV1alpha1::ComputeEngineDisksTargetDetails

ComputeEngineDisksTargetDetails is a collection of created Persistent Disks details. Corresponds to the JSON property computeEngineDisksTargetDetails



1713
1714
1715
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1713

def compute_engine_disks_target_details
  @compute_engine_disks_target_details
end

#compute_engine_target_detailsGoogle::Apis::VmmigrationV1alpha1::ComputeEngineTargetDetails

ComputeEngineTargetDetails is a collection of details for creating a VM in a target Compute Engine project. Corresponds to the JSON property computeEngineTargetDetails



1719
1720
1721
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1719

def compute_engine_target_details
  @compute_engine_target_details
end

#compute_engine_vm_detailsGoogle::Apis::VmmigrationV1alpha1::TargetVmDetails

TargetVMDetails is a collection of details for creating a VM in a target Compute Engine project. Corresponds to the JSON property computeEngineVmDetails



1725
1726
1727
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1725

def compute_engine_vm_details
  @compute_engine_vm_details
end

#create_timeString

Output only. The time the cutover job was created (as an API call, not when it was actually created in the target). Corresponds to the JSON property createTime

Returns:

  • (String)


1731
1732
1733
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1731

def create_time
  @create_time
end

#end_timeString

Output only. The time the cutover job had finished. Corresponds to the JSON property endTime

Returns:

  • (String)


1736
1737
1738
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1736

def end_time
  @end_time
end

#errorGoogle::Apis::VmmigrationV1alpha1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1746
1747
1748
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1746

def error
  @error
end

#nameString

Output only. The name of the cutover job. Corresponds to the JSON property name

Returns:

  • (String)


1751
1752
1753
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1751

def name
  @name
end

#progressFixnum

Output only. The current progress in percentage of the cutover job. Corresponds to the JSON property progress

Returns:

  • (Fixnum)


1756
1757
1758
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1756

def progress
  @progress
end

#progress_percentFixnum

Output only. The current progress in percentage of the cutover job. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


1761
1762
1763
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1761

def progress_percent
  @progress_percent
end

#stateString

Output only. State of the cutover job. Corresponds to the JSON property state

Returns:

  • (String)


1766
1767
1768
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1766

def state
  @state
end

#state_messageString

Output only. A message providing possible extra details about the current state. Corresponds to the JSON property stateMessage

Returns:

  • (String)


1772
1773
1774
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1772

def state_message
  @state_message
end

#state_timeString

Output only. The time the state was last updated. Corresponds to the JSON property stateTime

Returns:

  • (String)


1777
1778
1779
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1777

def state_time
  @state_time
end

#stepsArray<Google::Apis::VmmigrationV1alpha1::CutoverStep>

Output only. The cutover steps list representing its progress. Corresponds to the JSON property steps



1782
1783
1784
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1782

def steps
  @steps
end

#target_detailsGoogle::Apis::VmmigrationV1alpha1::TargetVmDetails

TargetVMDetails is a collection of details for creating a VM in a target Compute Engine project. Corresponds to the JSON property targetDetails



1788
1789
1790
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1788

def target_details
  @target_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1795

def update!(**args)
  @compute_engine_disks_target_details = args[:compute_engine_disks_target_details] if args.key?(:compute_engine_disks_target_details)
  @compute_engine_target_details = args[:compute_engine_target_details] if args.key?(:compute_engine_target_details)
  @compute_engine_vm_details = args[:compute_engine_vm_details] if args.key?(:compute_engine_vm_details)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @name = args[:name] if args.key?(:name)
  @progress = args[:progress] if args.key?(:progress)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @state_time = args[:state_time] if args.key?(:state_time)
  @steps = args[:steps] if args.key?(:steps)
  @target_details = args[:target_details] if args.key?(:target_details)
end