Class: Google::Apis::VmmigrationV1alpha1::CutoverStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

CutoverStep holds information about the cutover step progress.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CutoverStep

Returns a new instance of CutoverStep.



1854
1855
1856
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

The time the step has ended. Corresponds to the JSON property endTime

Returns:

  • (String)


1820
1821
1822
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1820

def end_time
  @end_time
end

#final_syncGoogle::Apis::VmmigrationV1alpha1::ReplicationCycle

ReplicationCycle contains information about the current replication cycle status. Corresponds to the JSON property finalSync



1826
1827
1828
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1826

def final_sync
  @final_sync
end

#instantiating_migrated_vmGoogle::Apis::VmmigrationV1alpha1::InstantiatingMigratedVmStep

InstantiatingMigratedVMStep contains specific step details. Corresponds to the JSON property instantiatingMigratedVm



1831
1832
1833
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1831

def instantiating_migrated_vm
  @instantiating_migrated_vm
end

#preparing_vm_disksGoogle::Apis::VmmigrationV1alpha1::PreparingVmDisksStep

PreparingVMDisksStep contains specific step details. Corresponds to the JSON property preparingVmDisks



1836
1837
1838
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1836

def preparing_vm_disks
  @preparing_vm_disks
end

#previous_replication_cycleGoogle::Apis::VmmigrationV1alpha1::ReplicationCycle

ReplicationCycle contains information about the current replication cycle status. Corresponds to the JSON property previousReplicationCycle



1842
1843
1844
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1842

def previous_replication_cycle
  @previous_replication_cycle
end

#shutting_down_source_vmGoogle::Apis::VmmigrationV1alpha1::ShuttingDownSourceVmStep

ShuttingDownSourceVMStep contains specific step details. Corresponds to the JSON property shuttingDownSourceVm



1847
1848
1849
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1847

def shutting_down_source_vm
  @shutting_down_source_vm
end

#start_timeString

The time the step has started. Corresponds to the JSON property startTime

Returns:

  • (String)


1852
1853
1854
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1852

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1859
1860
1861
1862
1863
1864
1865
1866
1867
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1859

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @final_sync = args[:final_sync] if args.key?(:final_sync)
  @instantiating_migrated_vm = args[:instantiating_migrated_vm] if args.key?(:instantiating_migrated_vm)
  @preparing_vm_disks = args[:preparing_vm_disks] if args.key?(:preparing_vm_disks)
  @previous_replication_cycle = args[:previous_replication_cycle] if args.key?(:previous_replication_cycle)
  @shutting_down_source_vm = args[:shutting_down_source_vm] if args.key?(:shutting_down_source_vm)
  @start_time = args[:start_time] if args.key?(:start_time)
end