Class: Google::Apis::VmmigrationV1alpha1::DatacenterConnector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

DatacenterConnector message describes a connector between the Source and Google Cloud, which is installed on a vmware datacenter (an OVA vm installed by the user) to connect the Datacenter to Google Cloud and support vm migration data transfer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatacenterConnector

Returns a new instance of DatacenterConnector.



2029
2030
2031
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appliance_infrastructure_versionString

Output only. Appliance OVA version. This is the OVA which is manually installed by the user and contains the infrastructure for the automatically updatable components on the appliance. Corresponds to the JSON property applianceInfrastructureVersion

Returns:

  • (String)


1950
1951
1952
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1950

def appliance_infrastructure_version
  @appliance_infrastructure_version
end

#appliance_software_versionString

Output only. Appliance last installed update bundle version. This is the version of the automatically updatable components on the appliance. Corresponds to the JSON property applianceSoftwareVersion

Returns:

  • (String)


1956
1957
1958
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1956

def appliance_software_version
  @appliance_software_version
end

#available_versionsGoogle::Apis::VmmigrationV1alpha1::AvailableUpdates

Holds information about the available versions for upgrade. Corresponds to the JSON property availableVersions



1961
1962
1963
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1961

def available_versions
  @available_versions
end

#bucketString

Output only. The communication channel between the datacenter connector and Google Cloud. Corresponds to the JSON property bucket

Returns:

  • (String)


1967
1968
1969
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1967

def bucket
  @bucket
end

#create_timeString

Output only. The time the connector was created (as an API call, not when it was actually installed). Corresponds to the JSON property createTime

Returns:

  • (String)


1973
1974
1975
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1973

def create_time
  @create_time
end

#errorGoogle::Apis::VmmigrationV1alpha1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1983
1984
1985
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1983

def error
  @error
end

#nameString

Output only. The connector's name. Corresponds to the JSON property name

Returns:

  • (String)


1988
1989
1990
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1988

def name
  @name
end

#registration_idString

Immutable. A unique key for this connector. This key is internal to the OVA connector and is supplied with its creation during the registration process and can not be modified. Corresponds to the JSON property registrationId

Returns:

  • (String)


1995
1996
1997
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 1995

def registration_id
  @registration_id
end

#service_accountString

The service account to use in the connector when communicating with the cloud. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


2000
2001
2002
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2000

def 
  @service_account
end

#stateString

Output only. State of the DatacenterConnector, as determined by the health checks. Corresponds to the JSON property state

Returns:

  • (String)


2006
2007
2008
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2006

def state
  @state
end

#state_timeString

Output only. The time the state was last set. Corresponds to the JSON property stateTime

Returns:

  • (String)


2011
2012
2013
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2011

def state_time
  @state_time
end

#update_timeString

Output only. The last time the connector was updated with an API call. Corresponds to the JSON property updateTime

Returns:

  • (String)


2016
2017
2018
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2016

def update_time
  @update_time
end

#upgrade_statusGoogle::Apis::VmmigrationV1alpha1::UpgradeStatus

UpgradeStatus contains information about upgradeAppliance operation. Corresponds to the JSON property upgradeStatus



2021
2022
2023
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2021

def upgrade_status
  @upgrade_status
end

#versionString

The version running in the DatacenterConnector. This is supplied by the OVA connector during the registration process and can not be modified. Corresponds to the JSON property version

Returns:

  • (String)


2027
2028
2029
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2027

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2034

def update!(**args)
  @appliance_infrastructure_version = args[:appliance_infrastructure_version] if args.key?(:appliance_infrastructure_version)
  @appliance_software_version = args[:appliance_software_version] if args.key?(:appliance_software_version)
  @available_versions = args[:available_versions] if args.key?(:available_versions)
  @bucket = args[:bucket] if args.key?(:bucket)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error = args[:error] if args.key?(:error)
  @name = args[:name] if args.key?(:name)
  @registration_id = args[:registration_id] if args.key?(:registration_id)
  @service_account = args[:service_account] if args.key?(:service_account)
  @state = args[:state] if args.key?(:state)
  @state_time = args[:state_time] if args.key?(:state_time)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upgrade_status = args[:upgrade_status] if args.key?(:upgrade_status)
  @version = args[:version] if args.key?(:version)
end