Class: Google::Apis::VmmigrationV1alpha1::DiskMigrationJobTargetDetails
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1alpha1::DiskMigrationJobTargetDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb
Overview
Details of the target disk in Compute Engine.
Instance Attribute Summary collapse
-
#encryption ⇒ Google::Apis::VmmigrationV1alpha1::Encryption
Encryption message describes the details of the applied encryption.
-
#labels ⇒ Hash<String,String>
Optional.
-
#target_disk ⇒ Google::Apis::VmmigrationV1alpha1::ComputeEngineDisk
Compute Engine disk target details.
-
#target_project ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskMigrationJobTargetDetails
constructor
A new instance of DiskMigrationJobTargetDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskMigrationJobTargetDetails
Returns a new instance of DiskMigrationJobTargetDetails.
2271 2272 2273 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption ⇒ Google::Apis::VmmigrationV1alpha1::Encryption
Encryption message describes the details of the applied encryption.
Corresponds to the JSON property encryption
2252 2253 2254 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2252 def encryption @encryption end |
#labels ⇒ Hash<String,String>
Optional. A map of labels to associate with the disk.
Corresponds to the JSON property labels
2257 2258 2259 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2257 def labels @labels end |
#target_disk ⇒ Google::Apis::VmmigrationV1alpha1::ComputeEngineDisk
Compute Engine disk target details.
Corresponds to the JSON property targetDisk
2262 2263 2264 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2262 def target_disk @target_disk end |
#target_project ⇒ String
Required. The name of the resource of type TargetProject which represents the
Compute Engine project in which to create the disk. Should be of the form:
projects/project/locations/global/targetProjects/target-project
Corresponds to the JSON property targetProject
2269 2270 2271 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2269 def target_project @target_project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2276 2277 2278 2279 2280 2281 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2276 def update!(**args) @encryption = args[:encryption] if args.key?(:encryption) @labels = args[:labels] if args.key?(:labels) @target_disk = args[:target_disk] if args.key?(:target_disk) @target_project = args[:target_project] if args.key?(:target_project) end |