Class: Google::Apis::VmmigrationV1alpha1::Group
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1alpha1::Group
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb
Overview
Describes message for 'Group' resource. The Group is a collections of several MigratingVms.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
User-provided description of the group.
-
#display_name ⇒ String
Display name is a user defined name for this group which can be updated.
-
#migration_target_type ⇒ String
Immutable.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Group
constructor
A new instance of Group.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Group
Returns a new instance of Group.
2693 2694 2695 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The create time timestamp.
Corresponds to the JSON property createTime
2666 2667 2668 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2666 def create_time @create_time end |
#description ⇒ String
User-provided description of the group.
Corresponds to the JSON property description
2671 2672 2673 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2671 def description @description end |
#display_name ⇒ String
Display name is a user defined name for this group which can be updated.
Corresponds to the JSON property displayName
2676 2677 2678 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2676 def display_name @display_name end |
#migration_target_type ⇒ String
Immutable. The target type of this group.
Corresponds to the JSON property migrationTargetType
2681 2682 2683 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2681 def migration_target_type @migration_target_type end |
#name ⇒ String
Output only. The Group name.
Corresponds to the JSON property name
2686 2687 2688 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2686 def name @name end |
#update_time ⇒ String
Output only. The update time timestamp.
Corresponds to the JSON property updateTime
2691 2692 2693 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2691 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2698 2699 2700 2701 2702 2703 2704 2705 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2698 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @migration_target_type = args[:migration_target_type] if args.key?(:migration_target_type) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |