Class: Google::Apis::VmmigrationV1alpha1::ImageImportJob
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1alpha1::ImageImportJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb
Overview
ImageImportJob describes the progress and result of an image import.
Instance Attribute Summary collapse
-
#cloud_storage_uri ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#created_resources ⇒ Array<String>
Output only.
-
#disk_image_target_details ⇒ Google::Apis::VmmigrationV1alpha1::DiskImageTargetDetails
The target details of the image resource that will be created by the import job.
-
#end_time ⇒ String
Output only.
-
#errors ⇒ Array<Google::Apis::VmmigrationV1alpha1::Status>
Output only.
-
#machine_image_target_details ⇒ Google::Apis::VmmigrationV1alpha1::MachineImageTargetDetails
The target details of the machine image resource that will be created by the image import job.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#steps ⇒ Array<Google::Apis::VmmigrationV1alpha1::ImageImportStep>
Output only.
-
#warnings ⇒ Array<Google::Apis::VmmigrationV1alpha1::MigrationWarning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageImportJob
constructor
A new instance of ImageImportJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageImportJob
Returns a new instance of ImageImportJob.
2832 2833 2834 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2832 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_storage_uri ⇒ String
Output only. The path to the Cloud Storage file from which the image should be
imported.
Corresponds to the JSON property cloudStorageUri
2775 2776 2777 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2775 def cloud_storage_uri @cloud_storage_uri end |
#create_time ⇒ String
Output only. The time the image import was created (as an API call, not when
it was actually created in the target).
Corresponds to the JSON property createTime
2781 2782 2783 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2781 def create_time @create_time end |
#created_resources ⇒ Array<String>
Output only. The resource paths of the resources created by the image import
job.
Corresponds to the JSON property createdResources
2787 2788 2789 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2787 def created_resources @created_resources end |
#disk_image_target_details ⇒ Google::Apis::VmmigrationV1alpha1::DiskImageTargetDetails
The target details of the image resource that will be created by the import
job.
Corresponds to the JSON property diskImageTargetDetails
2793 2794 2795 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2793 def disk_image_target_details @disk_image_target_details end |
#end_time ⇒ String
Output only. The time the image import was ended.
Corresponds to the JSON property endTime
2798 2799 2800 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2798 def end_time @end_time end |
#errors ⇒ Array<Google::Apis::VmmigrationV1alpha1::Status>
Output only. Provides details on the error that led to the image import state
in case of an error.
Corresponds to the JSON property errors
2804 2805 2806 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2804 def errors @errors end |
#machine_image_target_details ⇒ Google::Apis::VmmigrationV1alpha1::MachineImageTargetDetails
The target details of the machine image resource that will be created by the
image import job.
Corresponds to the JSON property machineImageTargetDetails
2810 2811 2812 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2810 def machine_image_target_details @machine_image_target_details end |
#name ⇒ String
Output only. The resource path of the ImageImportJob.
Corresponds to the JSON property name
2815 2816 2817 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2815 def name @name end |
#state ⇒ String
Output only. The state of the image import.
Corresponds to the JSON property state
2820 2821 2822 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2820 def state @state end |
#steps ⇒ Array<Google::Apis::VmmigrationV1alpha1::ImageImportStep>
Output only. The image import steps list representing its progress.
Corresponds to the JSON property steps
2825 2826 2827 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2825 def steps @steps end |
#warnings ⇒ Array<Google::Apis::VmmigrationV1alpha1::MigrationWarning>
Output only. Warnings that occurred during the image import.
Corresponds to the JSON property warnings
2830 2831 2832 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2830 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2837 2838 2839 2840 2841 2842 2843 2844 2845 2846 2847 2848 2849 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2837 def update!(**args) @cloud_storage_uri = args[:cloud_storage_uri] if args.key?(:cloud_storage_uri) @create_time = args[:create_time] if args.key?(:create_time) @created_resources = args[:created_resources] if args.key?(:created_resources) @disk_image_target_details = args[:disk_image_target_details] if args.key?(:disk_image_target_details) @end_time = args[:end_time] if args.key?(:end_time) @errors = args[:errors] if args.key?(:errors) @machine_image_target_details = args[:machine_image_target_details] if args.key?(:machine_image_target_details) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @steps = args[:steps] if args.key?(:steps) @warnings = args[:warnings] if args.key?(:warnings) end |