Class: Google::Apis::VmmigrationV1alpha1::ImageImportOsAdaptationParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

Parameters affecting the OS adaptation process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageImportOsAdaptationParameters

Returns a new instance of ImageImportOsAdaptationParameters.



2884
2885
2886
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptation_modifiersArray<Google::Apis::VmmigrationV1alpha1::AdaptationModifier>

Optional. Modifiers to be used as configuration of the OS adaptation process. Corresponds to the JSON property adaptationModifiers



2859
2860
2861
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2859

def adaptation_modifiers
  @adaptation_modifiers
end

#boot_conversionString

Optional. By default the image will keep its existing boot option. Setting this property will trigger an internal process which will convert the image from using the existing boot option to another. The size of the boot disk might be increased to allow the conversion Corresponds to the JSON property bootConversion

Returns:

  • (String)


2867
2868
2869
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2867

def boot_conversion
  @boot_conversion
end

#generalizeBoolean Also known as: generalize?

Optional. Set to true in order to generalize the imported image. The generalization process enables co-existence of multiple VMs created from the same image. For Windows, generalizing the image removes computer-specific information such as installed drivers and the computer security identifier ( SID). Corresponds to the JSON property generalize

Returns:

  • (Boolean)


2876
2877
2878
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2876

def generalize
  @generalize
end

#license_typeString

Optional. Choose which type of license to apply to the imported image. Corresponds to the JSON property licenseType

Returns:

  • (String)


2882
2883
2884
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2882

def license_type
  @license_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2889
2890
2891
2892
2893
2894
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2889

def update!(**args)
  @adaptation_modifiers = args[:adaptation_modifiers] if args.key?(:adaptation_modifiers)
  @boot_conversion = args[:boot_conversion] if args.key?(:boot_conversion)
  @generalize = args[:generalize] if args.key?(:generalize)
  @license_type = args[:license_type] if args.key?(:license_type)
end