Class: Google::Apis::VmmigrationV1alpha1::MigratingVm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

MigratingVm describes the VM that will be migrated from a Source environment and its replication state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigratingVm

Returns a new instance of MigratingVm.



3820
3821
3822
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aws_source_vm_detailsGoogle::Apis::VmmigrationV1alpha1::AwsSourceVmDetails

Represent the source AWS VM details. Corresponds to the JSON property awsSourceVmDetails



3672
3673
3674
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3672

def aws_source_vm_details
  @aws_source_vm_details
end

#azure_source_vm_detailsGoogle::Apis::VmmigrationV1alpha1::AzureSourceVmDetails

Represent the source Azure VM details. Corresponds to the JSON property azureSourceVmDetails



3677
3678
3679
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3677

def azure_source_vm_details
  @azure_source_vm_details
end

#compute_engine_disks_target_defaultsGoogle::Apis::VmmigrationV1alpha1::ComputeEngineDisksTargetDefaults

ComputeEngineDisksTargetDefaults is a collection of details for creating Persistent Disks in a target Compute Engine project. Corresponds to the JSON property computeEngineDisksTargetDefaults



3683
3684
3685
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3683

def compute_engine_disks_target_defaults
  @compute_engine_disks_target_defaults
end

#compute_engine_target_defaultsGoogle::Apis::VmmigrationV1alpha1::ComputeEngineTargetDefaults

ComputeEngineTargetDefaults is a collection of details for creating a VM in a target Compute Engine project. Corresponds to the JSON property computeEngineTargetDefaults



3689
3690
3691
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3689

def compute_engine_target_defaults
  @compute_engine_target_defaults
end

#compute_engine_vm_defaultsGoogle::Apis::VmmigrationV1alpha1::TargetVmDetails

TargetVMDetails is a collection of details for creating a VM in a target Compute Engine project. Corresponds to the JSON property computeEngineVmDefaults



3695
3696
3697
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3695

def compute_engine_vm_defaults
  @compute_engine_vm_defaults
end

#create_timeString

Output only. The time the migrating VM was created (this refers to this resource and not to the time it was installed in the source). Corresponds to the JSON property createTime

Returns:

  • (String)


3701
3702
3703
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3701

def create_time
  @create_time
end

#current_sync_infoGoogle::Apis::VmmigrationV1alpha1::ReplicationCycle

ReplicationCycle contains information about the current replication cycle status. Corresponds to the JSON property currentSyncInfo



3707
3708
3709
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3707

def current_sync_info
  @current_sync_info
end

#cutover_forecastGoogle::Apis::VmmigrationV1alpha1::CutoverForecast

CutoverForecast holds information about future CutoverJobs of a MigratingVm. Corresponds to the JSON property cutoverForecast



3712
3713
3714
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3712

def cutover_forecast
  @cutover_forecast
end

#descriptionString

The description attached to the migrating VM by the user. Corresponds to the JSON property description

Returns:

  • (String)


3717
3718
3719
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3717

def description
  @description
end

#display_nameString

The display name attached to the MigratingVm by the user. Corresponds to the JSON property displayName

Returns:

  • (String)


3722
3723
3724
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3722

def display_name
  @display_name
end

#errorGoogle::Apis::VmmigrationV1alpha1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3732
3733
3734
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3732

def error
  @error
end

#expirationGoogle::Apis::VmmigrationV1alpha1::Expiration

Expiration holds information about the expiration of a MigratingVm. Corresponds to the JSON property expiration



3737
3738
3739
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3737

def expiration
  @expiration
end

#groupString

Output only. The group this migrating vm is included in, if any. The group is represented by the full path of the appropriate Group resource. Corresponds to the JSON property group

Returns:

  • (String)


3743
3744
3745
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3743

def group
  @group
end

#labelsHash<String,String>

The labels of the migrating VM. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3748
3749
3750
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3748

def labels
  @labels
end

#last_replication_cycleGoogle::Apis::VmmigrationV1alpha1::ReplicationCycle

ReplicationCycle contains information about the current replication cycle status. Corresponds to the JSON property lastReplicationCycle



3754
3755
3756
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3754

def last_replication_cycle
  @last_replication_cycle
end

#last_syncGoogle::Apis::VmmigrationV1alpha1::ReplicationSync

ReplicationSync contain information about the last replica sync to the cloud. Corresponds to the JSON property lastSync



3759
3760
3761
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3759

def last_sync
  @last_sync
end

#nameString

Output only. The identifier of the MigratingVm. Corresponds to the JSON property name

Returns:

  • (String)


3764
3765
3766
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3764

def name
  @name
end

#policyGoogle::Apis::VmmigrationV1alpha1::SchedulePolicy

A policy for scheduling replications. Corresponds to the JSON property policy



3769
3770
3771
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3769

def policy
  @policy
end

#recent_clone_jobsArray<Google::Apis::VmmigrationV1alpha1::CloneJob>

Output only. The recent clone jobs performed on the migrating VM. This field holds the vm's last completed clone job and the vm's running clone job, if one exists. Note: To have this field populated you need to explicitly request it via the "view" parameter of the Get/List request. Corresponds to the JSON property recentCloneJobs



3777
3778
3779
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3777

def recent_clone_jobs
  @recent_clone_jobs
end

#recent_cutover_jobsArray<Google::Apis::VmmigrationV1alpha1::CutoverJob>

Output only. The recent cutover jobs performed on the migrating VM. This field holds the vm's last completed cutover job and the vm's running cutover job, if one exists. Note: To have this field populated you need to explicitly request it via the "view" parameter of the Get/List request. Corresponds to the JSON property recentCutoverJobs



3785
3786
3787
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3785

def recent_cutover_jobs
  @recent_cutover_jobs
end

#source_vm_idString

The unique ID of the VM in the source. The VM's name in vSphere can be changed, so this is not the VM's name but rather its moRef id. This id is of the form vm-. Corresponds to the JSON property sourceVmId

Returns:

  • (String)


3792
3793
3794
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3792

def source_vm_id
  @source_vm_id
end

#stateString

Output only. State of the MigratingVm. Corresponds to the JSON property state

Returns:

  • (String)


3797
3798
3799
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3797

def state
  @state
end

#state_timeString

Output only. The last time the migrating VM state was updated. Corresponds to the JSON property stateTime

Returns:

  • (String)


3802
3803
3804
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3802

def state_time
  @state_time
end

#target_defaultsGoogle::Apis::VmmigrationV1alpha1::TargetVmDetails

TargetVMDetails is a collection of details for creating a VM in a target Compute Engine project. Corresponds to the JSON property targetDefaults



3808
3809
3810
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3808

def target_defaults
  @target_defaults
end

#update_timeString

Output only. The last time the migrating VM resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3813
3814
3815
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3813

def update_time
  @update_time
end

#vmware_source_vm_detailsGoogle::Apis::VmmigrationV1alpha1::VmwareSourceVmDetails

Represent the source Vmware VM details. Corresponds to the JSON property vmwareSourceVmDetails



3818
3819
3820
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3818

def vmware_source_vm_details
  @vmware_source_vm_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3825
3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3825

def update!(**args)
  @aws_source_vm_details = args[:aws_source_vm_details] if args.key?(:aws_source_vm_details)
  @azure_source_vm_details = args[:azure_source_vm_details] if args.key?(:azure_source_vm_details)
  @compute_engine_disks_target_defaults = args[:compute_engine_disks_target_defaults] if args.key?(:compute_engine_disks_target_defaults)
  @compute_engine_target_defaults = args[:compute_engine_target_defaults] if args.key?(:compute_engine_target_defaults)
  @compute_engine_vm_defaults = args[:compute_engine_vm_defaults] if args.key?(:compute_engine_vm_defaults)
  @create_time = args[:create_time] if args.key?(:create_time)
  @current_sync_info = args[:current_sync_info] if args.key?(:current_sync_info)
  @cutover_forecast = args[:cutover_forecast] if args.key?(:cutover_forecast)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @expiration = args[:expiration] if args.key?(:expiration)
  @group = args[:group] if args.key?(:group)
  @labels = args[:labels] if args.key?(:labels)
  @last_replication_cycle = args[:last_replication_cycle] if args.key?(:last_replication_cycle)
  @last_sync = args[:last_sync] if args.key?(:last_sync)
  @name = args[:name] if args.key?(:name)
  @policy = args[:policy] if args.key?(:policy)
  @recent_clone_jobs = args[:recent_clone_jobs] if args.key?(:recent_clone_jobs)
  @recent_cutover_jobs = args[:recent_cutover_jobs] if args.key?(:recent_cutover_jobs)
  @source_vm_id = args[:source_vm_id] if args.key?(:source_vm_id)
  @state = args[:state] if args.key?(:state)
  @state_time = args[:state_time] if args.key?(:state_time)
  @target_defaults = args[:target_defaults] if args.key?(:target_defaults)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vmware_source_vm_details = args[:vmware_source_vm_details] if args.key?(:vmware_source_vm_details)
end