Class: Google::Apis::VmmigrationV1alpha1::MigrationWarning

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

Represents migration resource warning information that can be used with google. rpc.Status message. MigrationWarning is used to present the user with warning information in migration operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrationWarning

Returns a new instance of MigrationWarning.



3943
3944
3945
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3943

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_itemGoogle::Apis::VmmigrationV1alpha1::LocalizedMessage

Provides a localized error message that is safe to return to the user which can be attached to an RPC error. Corresponds to the JSON property actionItem



3919
3920
3921
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3919

def action_item
  @action_item
end

#codeString

The warning code. Corresponds to the JSON property code

Returns:

  • (String)


3924
3925
3926
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3924

def code
  @code
end

Output only. URL(s) pointing to additional information on handling the current warning. Corresponds to the JSON property helpLinks



3930
3931
3932
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3930

def help_links
  @help_links
end

#warning_messageGoogle::Apis::VmmigrationV1alpha1::LocalizedMessage

Provides a localized error message that is safe to return to the user which can be attached to an RPC error. Corresponds to the JSON property warningMessage



3936
3937
3938
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3936

def warning_message
  @warning_message
end

#warning_timeString

The time the warning occurred. Corresponds to the JSON property warningTime

Returns:

  • (String)


3941
3942
3943
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3941

def warning_time
  @warning_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3948
3949
3950
3951
3952
3953
3954
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3948

def update!(**args)
  @action_item = args[:action_item] if args.key?(:action_item)
  @code = args[:code] if args.key?(:code)
  @help_links = args[:help_links] if args.key?(:help_links)
  @warning_message = args[:warning_message] if args.key?(:warning_message)
  @warning_time = args[:warning_time] if args.key?(:warning_time)
end