Class: Google::Apis::VmmigrationV1alpha1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



4177
4178
4179
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4177

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


4141
4142
4143
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4141

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4146
4147
4148
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4146

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


4151
4152
4153
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4151

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


4159
4160
4161
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4159

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


4165
4166
4167
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4165

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


4170
4171
4172
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4170

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


4175
4176
4177
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4175

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4182
4183
4184
4185
4186
4187
4188
4189
4190
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4182

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end