Class: Google::Apis::VmmigrationV1alpha1::ReplicationCycle

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

ReplicationCycle contains information about the current replication cycle status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplicationCycle

Returns a new instance of ReplicationCycle.



4441
4442
4443
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cycle_numberFixnum

The cycle's ordinal number. Corresponds to the JSON property cycleNumber

Returns:

  • (Fixnum)


4383
4384
4385
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4383

def cycle_number
  @cycle_number
end

#end_timeString

The time the replication cycle has ended. Corresponds to the JSON property endTime

Returns:

  • (String)


4388
4389
4390
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4388

def end_time
  @end_time
end

#errorGoogle::Apis::VmmigrationV1alpha1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4398
4399
4400
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4398

def error
  @error
end

#nameString

The identifier of the ReplicationCycle. Corresponds to the JSON property name

Returns:

  • (String)


4403
4404
4405
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4403

def name
  @name
end

#progressFixnum

The current progress in percentage of this cycle. Corresponds to the JSON property progress

Returns:

  • (Fixnum)


4408
4409
4410
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4408

def progress
  @progress
end

#progress_percentFixnum

The current progress in percentage of this cycle. Was replaced by 'steps' field, which breaks down the cycle progression more accurately. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


4414
4415
4416
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4414

def progress_percent
  @progress_percent
end

#start_timeString

The time the replication cycle has started. Corresponds to the JSON property startTime

Returns:

  • (String)


4419
4420
4421
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4419

def start_time
  @start_time
end

#stateString

State of the ReplicationCycle. Corresponds to the JSON property state

Returns:

  • (String)


4424
4425
4426
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4424

def state
  @state
end

#stepsArray<Google::Apis::VmmigrationV1alpha1::CycleStep>

The cycle's steps list representing its progress. Corresponds to the JSON property steps



4429
4430
4431
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4429

def steps
  @steps
end

#total_pause_durationString

The accumulated duration the replication cycle was paused. Corresponds to the JSON property totalPauseDuration

Returns:

  • (String)


4434
4435
4436
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4434

def total_pause_duration
  @total_pause_duration
end

#warningsArray<Google::Apis::VmmigrationV1alpha1::MigrationWarning>

Output only. Warnings that occurred during the cycle. Corresponds to the JSON property warnings



4439
4440
4441
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4439

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4446
4447
4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4446

def update!(**args)
  @cycle_number = args[:cycle_number] if args.key?(:cycle_number)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @name = args[:name] if args.key?(:name)
  @progress = args[:progress] if args.key?(:progress)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @steps = args[:steps] if args.key?(:steps)
  @total_pause_duration = args[:total_pause_duration] if args.key?(:total_pause_duration)
  @warnings = args[:warnings] if args.key?(:warnings)
end