Class: Google::Apis::VmmigrationV1alpha1::ReplicationSync

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

ReplicationSync contain information about the last replica sync to the cloud.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplicationSync

Returns a new instance of ReplicationSync.



4464
4465
4466
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_sync_timeString

The most updated snapshot created time in the source that finished replication. Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


4462
4463
4464
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4462

def last_sync_time
  @last_sync_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4469
4470
4471
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4469

def update!(**args)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
end