Class: Google::Apis::VmmigrationV1alpha1::Source

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

Source message describes a specific vm migration Source resource. It contains the source environment information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Source

Returns a new instance of Source.



4718
4719
4720
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#awsGoogle::Apis::VmmigrationV1alpha1::AwsSourceDetails

AwsSourceDetails message describes a specific source details for the AWS source type. Corresponds to the JSON property aws



4664
4665
4666
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4664

def aws
  @aws
end

#azureGoogle::Apis::VmmigrationV1alpha1::AzureSourceDetails

AzureSourceDetails message describes a specific source details for the Azure source type. Corresponds to the JSON property azure



4670
4671
4672
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4670

def azure
  @azure
end

#create_timeString

Output only. The create time timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


4675
4676
4677
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4675

def create_time
  @create_time
end

#descriptionString

User-provided description of the source. Corresponds to the JSON property description

Returns:

  • (String)


4680
4681
4682
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4680

def description
  @description
end

#encryptionGoogle::Apis::VmmigrationV1alpha1::Encryption

Encryption message describes the details of the applied encryption. Corresponds to the JSON property encryption



4685
4686
4687
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4685

def encryption
  @encryption
end

#errorGoogle::Apis::VmmigrationV1alpha1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4695
4696
4697
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4695

def error
  @error
end

#labelsHash<String,String>

The labels of the source. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4700
4701
4702
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4700

def labels
  @labels
end

#nameString

Output only. The Source name. Corresponds to the JSON property name

Returns:

  • (String)


4705
4706
4707
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4705

def name
  @name
end

#update_timeString

Output only. The update time timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


4710
4711
4712
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4710

def update_time
  @update_time
end

#vmwareGoogle::Apis::VmmigrationV1alpha1::VmwareSourceDetails

VmwareSourceDetails message describes a specific source details for the vmware source type. Corresponds to the JSON property vmware



4716
4717
4718
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4716

def vmware
  @vmware
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4723

def update!(**args)
  @aws = args[:aws] if args.key?(:aws)
  @azure = args[:azure] if args.key?(:azure)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @encryption = args[:encryption] if args.key?(:encryption)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vmware = args[:vmware] if args.key?(:vmware)
end