Class: Google::Apis::VmmigrationV1alpha1::TargetProject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

TargetProject message represents a target Compute Engine project for a migration or a clone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetProject

Returns a new instance of TargetProject.



4864
4865
4866
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time this target project resource was created (not related to when the Compute Engine project it points to was created). Corresponds to the JSON property createTime

Returns:

  • (String)


4842
4843
4844
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4842

def create_time
  @create_time
end

#descriptionString

The target project's description. Corresponds to the JSON property description

Returns:

  • (String)


4847
4848
4849
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4847

def description
  @description
end

#nameString

Output only. The name of the target project. Corresponds to the JSON property name

Returns:

  • (String)


4852
4853
4854
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4852

def name
  @name
end

#projectString

Required. The target project ID (number) or project name. Corresponds to the JSON property project

Returns:

  • (String)


4857
4858
4859
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4857

def project
  @project
end

#update_timeString

Output only. The last time the target project resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4862
4863
4864
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4862

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4869
4870
4871
4872
4873
4874
4875
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4869

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @project = args[:project] if args.key?(:project)
  @update_time = args[:update_time] if args.key?(:update_time)
end