Class: Google::Apis::VmmigrationV1alpha1::UtilizationReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

Utilization report details the utilization (CPU, memory, etc.) of selected source VMs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UtilizationReport

Returns a new instance of UtilizationReport.



5171
5172
5173
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the report was created (this refers to the time of the request, not the time the report creation completed). Corresponds to the JSON property createTime

Returns:

  • (String)


5109
5110
5111
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5109

def create_time
  @create_time
end

#display_nameString

The report display name, as assigned by the user. Corresponds to the JSON property displayName

Returns:

  • (String)


5114
5115
5116
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5114

def display_name
  @display_name
end

#errorGoogle::Apis::VmmigrationV1alpha1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



5124
5125
5126
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5124

def error
  @error
end

#frame_end_timeString

Output only. The point in time when the time frame ends. Notice that the time frame is counted backwards. For instance if the "frame_end_time" value is 2021/ 01/20 and the time frame is WEEK then the report covers the week between 2021/ 01/20 and 2021/01/14. Corresponds to the JSON property frameEndTime

Returns:

  • (String)


5132
5133
5134
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5132

def frame_end_time
  @frame_end_time
end

#nameString

Output only. The report unique name. Corresponds to the JSON property name

Returns:

  • (String)


5137
5138
5139
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5137

def name
  @name
end

#stateString

Output only. Current state of the report. Corresponds to the JSON property state

Returns:

  • (String)


5142
5143
5144
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5142

def state
  @state
end

#state_timeString

Output only. The time the state was last set. Corresponds to the JSON property stateTime

Returns:

  • (String)


5147
5148
5149
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5147

def state_time
  @state_time
end

#time_frameString

Time frame of the report. Corresponds to the JSON property timeFrame

Returns:

  • (String)


5152
5153
5154
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5152

def time_frame
  @time_frame
end

#vm_countFixnum

Output only. Total number of VMs included in the report. Corresponds to the JSON property vmCount

Returns:

  • (Fixnum)


5157
5158
5159
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5157

def vm_count
  @vm_count
end

#vmsArray<Google::Apis::VmmigrationV1alpha1::VmUtilizationInfo>

List of utilization information per VM. When sent as part of the request, the " vm_id" field is used in order to specify which VMs to include in the report. In that case all other fields are ignored. Corresponds to the JSON property vms



5164
5165
5166
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5164

def vms
  @vms
end

#vms_countFixnum

Output only. Total number of VMs included in the report. Corresponds to the JSON property vmsCount

Returns:

  • (Fixnum)


5169
5170
5171
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5169

def vms_count
  @vms_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
5186
5187
5188
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5176

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @frame_end_time = args[:frame_end_time] if args.key?(:frame_end_time)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_time = args[:state_time] if args.key?(:state_time)
  @time_frame = args[:time_frame] if args.key?(:time_frame)
  @vm_count = args[:vm_count] if args.key?(:vm_count)
  @vms = args[:vms] if args.key?(:vms)
  @vms_count = args[:vms_count] if args.key?(:vms_count)
end