Class: Google::Apis::VmmigrationV1alpha1::VmwareVmDetails
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1alpha1::VmwareVmDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb
Overview
VmwareVmDetails describes a VM in vCenter.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#boot_option ⇒ String
Output only.
-
#committed_storage ⇒ Fixnum
The total size of the storage allocated to the VM in MB.
-
#committed_storage_mb ⇒ Fixnum
The total size of the storage allocated to the VM in MB.
-
#cpu_count ⇒ Fixnum
The number of cpus in the VM.
-
#datacenter_description ⇒ String
The descriptive name of the vCenter's datacenter this VM is contained in.
-
#datacenter_id ⇒ String
The id of the vCenter's datacenter this VM is contained in.
-
#disk_count ⇒ Fixnum
The number of disks the VM has.
-
#display_name ⇒ String
The display name of the VM.
-
#guest_description ⇒ String
The VM's OS.
-
#memory_mb ⇒ Fixnum
The size of the memory of the VM in MB.
-
#power_state ⇒ String
The power state of the VM at the moment list was taken.
-
#uuid ⇒ String
The unique identifier of the VM in vCenter.
-
#vm_id ⇒ String
The VM's id in the source (note that this is not the MigratingVm's id).
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareVmDetails
constructor
A new instance of VmwareVmDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareVmDetails
Returns a new instance of VmwareVmDetails.
5578 5579 5580 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5578 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. The CPU architecture.
Corresponds to the JSON property architecture
5507 5508 5509 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5507 def architecture @architecture end |
#boot_option ⇒ String
Output only. The VM Boot Option.
Corresponds to the JSON property bootOption
5512 5513 5514 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5512 def boot_option @boot_option end |
#committed_storage ⇒ Fixnum
The total size of the storage allocated to the VM in MB.
Corresponds to the JSON property committedStorage
5517 5518 5519 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5517 def committed_storage @committed_storage end |
#committed_storage_mb ⇒ Fixnum
The total size of the storage allocated to the VM in MB.
Corresponds to the JSON property committedStorageMb
5522 5523 5524 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5522 def committed_storage_mb @committed_storage_mb end |
#cpu_count ⇒ Fixnum
The number of cpus in the VM.
Corresponds to the JSON property cpuCount
5527 5528 5529 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5527 def cpu_count @cpu_count end |
#datacenter_description ⇒ String
The descriptive name of the vCenter's datacenter this VM is contained in.
Corresponds to the JSON property datacenterDescription
5532 5533 5534 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5532 def datacenter_description @datacenter_description end |
#datacenter_id ⇒ String
The id of the vCenter's datacenter this VM is contained in.
Corresponds to the JSON property datacenterId
5537 5538 5539 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5537 def datacenter_id @datacenter_id end |
#disk_count ⇒ Fixnum
The number of disks the VM has.
Corresponds to the JSON property diskCount
5542 5543 5544 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5542 def disk_count @disk_count end |
#display_name ⇒ String
The display name of the VM. Note that this is not necessarily unique.
Corresponds to the JSON property displayName
5547 5548 5549 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5547 def display_name @display_name end |
#guest_description ⇒ String
The VM's OS. See for example https://vdc-repo.vmware.com/vmwb-repository/dcr-
public/da47f910-60ac-438b-8b9b-6122f4d14524/16b7274a-bf8b-4b4c-a05e-
746f2aa93c8c/doc/vim.vm.GuestOsDescriptor.GuestOsIdentifier.html for types of
strings this might hold.
Corresponds to the JSON property guestDescription
5555 5556 5557 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5555 def guest_description @guest_description end |
#memory_mb ⇒ Fixnum
The size of the memory of the VM in MB.
Corresponds to the JSON property memoryMb
5560 5561 5562 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5560 def memory_mb @memory_mb end |
#power_state ⇒ String
The power state of the VM at the moment list was taken.
Corresponds to the JSON property powerState
5565 5566 5567 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5565 def power_state @power_state end |
#uuid ⇒ String
The unique identifier of the VM in vCenter.
Corresponds to the JSON property uuid
5570 5571 5572 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5570 def uuid @uuid end |
#vm_id ⇒ String
The VM's id in the source (note that this is not the MigratingVm's id). This
is the moref id of the VM.
Corresponds to the JSON property vmId
5576 5577 5578 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5576 def vm_id @vm_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5583 5584 5585 5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5583 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @boot_option = args[:boot_option] if args.key?(:boot_option) @committed_storage = args[:committed_storage] if args.key?(:committed_storage) @committed_storage_mb = args[:committed_storage_mb] if args.key?(:committed_storage_mb) @cpu_count = args[:cpu_count] if args.key?(:cpu_count) @datacenter_description = args[:datacenter_description] if args.key?(:datacenter_description) @datacenter_id = args[:datacenter_id] if args.key?(:datacenter_id) @disk_count = args[:disk_count] if args.key?(:disk_count) @display_name = args[:display_name] if args.key?(:display_name) @guest_description = args[:guest_description] if args.key?(:guest_description) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @power_state = args[:power_state] if args.key?(:power_state) @uuid = args[:uuid] if args.key?(:uuid) @vm_id = args[:vm_id] if args.key?(:vm_id) end |