Class: Google::Apis::VmmigrationV1alpha1::DisksMigrationVmTargetDefaults
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1alpha1::DisksMigrationVmTargetDefaults
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb
Overview
Details for creation of a VM that migrated data disks will be attached to.
Instance Attribute Summary collapse
-
#additional_licenses ⇒ Array<String>
Optional.
-
#boot_disk_defaults ⇒ Google::Apis::VmmigrationV1alpha1::BootDiskDefaults
BootDiskDefaults hold information about the boot disk of a VM.
-
#compute_scheduling ⇒ Google::Apis::VmmigrationV1alpha1::ComputeScheduling
Scheduling information for VM on maintenance/restart behaviour and node allocation in sole tenant nodes.
-
#enable_integrity_monitoring ⇒ Boolean
(also: #enable_integrity_monitoring?)
Optional.
-
#enable_vtpm ⇒ Boolean
(also: #enable_vtpm?)
Optional.
-
#encryption ⇒ Google::Apis::VmmigrationV1alpha1::Encryption
Encryption message describes the details of the applied encryption.
-
#hostname ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#machine_type ⇒ String
Required.
-
#machine_type_series ⇒ String
Optional.
-
#metadata ⇒ Hash<String,String>
Optional.
-
#network_interfaces ⇒ Array<Google::Apis::VmmigrationV1alpha1::NetworkInterface>
Optional.
-
#network_tags ⇒ Array<String>
Optional.
-
#secure_boot ⇒ Boolean
(also: #secure_boot?)
Optional.
-
#service_account ⇒ String
Optional.
-
#vm_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DisksMigrationVmTargetDefaults
constructor
A new instance of DisksMigrationVmTargetDefaults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DisksMigrationVmTargetDefaults
Returns a new instance of DisksMigrationVmTargetDefaults.
2443 2444 2445 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_licenses ⇒ Array<String>
Optional. Additional licenses to assign to the VM.
Corresponds to the JSON property additionalLicenses
2360 2361 2362 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2360 def additional_licenses @additional_licenses end |
#boot_disk_defaults ⇒ Google::Apis::VmmigrationV1alpha1::BootDiskDefaults
BootDiskDefaults hold information about the boot disk of a VM.
Corresponds to the JSON property bootDiskDefaults
2365 2366 2367 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2365 def boot_disk_defaults @boot_disk_defaults end |
#compute_scheduling ⇒ Google::Apis::VmmigrationV1alpha1::ComputeScheduling
Scheduling information for VM on maintenance/restart behaviour and node
allocation in sole tenant nodes. Options for instance behavior when the host
machine undergoes maintenance that may temporarily impact instance performance.
Corresponds to the JSON property computeScheduling
2372 2373 2374 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2372 def compute_scheduling @compute_scheduling end |
#enable_integrity_monitoring ⇒ Boolean Also known as: enable_integrity_monitoring?
Optional. Defines whether the instance has integrity monitoring enabled.
Corresponds to the JSON property enableIntegrityMonitoring
2377 2378 2379 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2377 def enable_integrity_monitoring @enable_integrity_monitoring end |
#enable_vtpm ⇒ Boolean Also known as: enable_vtpm?
Optional. Defines whether the instance has vTPM enabled.
Corresponds to the JSON property enableVtpm
2383 2384 2385 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2383 def enable_vtpm @enable_vtpm end |
#encryption ⇒ Google::Apis::VmmigrationV1alpha1::Encryption
Encryption message describes the details of the applied encryption.
Corresponds to the JSON property encryption
2389 2390 2391 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2389 def encryption @encryption end |
#hostname ⇒ String
Optional. The hostname to assign to the VM.
Corresponds to the JSON property hostname
2394 2395 2396 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2394 def hostname @hostname end |
#labels ⇒ Hash<String,String>
Optional. A map of labels to associate with the VM.
Corresponds to the JSON property labels
2399 2400 2401 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2399 def labels @labels end |
#machine_type ⇒ String
Required. The machine type to create the VM with.
Corresponds to the JSON property machineType
2404 2405 2406 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2404 def machine_type @machine_type end |
#machine_type_series ⇒ String
Optional. The machine type series to create the VM with. For presentation only.
Corresponds to the JSON property machineTypeSeries
2409 2410 2411 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2409 def machine_type_series @machine_type_series end |
#metadata ⇒ Hash<String,String>
Optional. The metadata key/value pairs to assign to the VM.
Corresponds to the JSON property metadata
2414 2415 2416 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2414 def @metadata end |
#network_interfaces ⇒ Array<Google::Apis::VmmigrationV1alpha1::NetworkInterface>
Optional. NICs to attach to the VM.
Corresponds to the JSON property networkInterfaces
2419 2420 2421 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2419 def network_interfaces @network_interfaces end |
#network_tags ⇒ Array<String>
Optional. A list of network tags to associate with the VM.
Corresponds to the JSON property networkTags
2424 2425 2426 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2424 def @network_tags end |
#secure_boot ⇒ Boolean Also known as: secure_boot?
Optional. Defines whether the instance has Secure Boot enabled. This can be
set to true only if the VM boot option is EFI.
Corresponds to the JSON property secureBoot
2430 2431 2432 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2430 def secure_boot @secure_boot end |
#service_account ⇒ String
Optional. The service account to associate the VM with.
Corresponds to the JSON property serviceAccount
2436 2437 2438 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2436 def service_account @service_account end |
#vm_name ⇒ String
Required. The name of the VM to create.
Corresponds to the JSON property vmName
2441 2442 2443 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2441 def vm_name @vm_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2448 def update!(**args) @additional_licenses = args[:additional_licenses] if args.key?(:additional_licenses) @boot_disk_defaults = args[:boot_disk_defaults] if args.key?(:boot_disk_defaults) @compute_scheduling = args[:compute_scheduling] if args.key?(:compute_scheduling) @enable_integrity_monitoring = args[:enable_integrity_monitoring] if args.key?(:enable_integrity_monitoring) @enable_vtpm = args[:enable_vtpm] if args.key?(:enable_vtpm) @encryption = args[:encryption] if args.key?(:encryption) @hostname = args[:hostname] if args.key?(:hostname) @labels = args[:labels] if args.key?(:labels) @machine_type = args[:machine_type] if args.key?(:machine_type) @machine_type_series = args[:machine_type_series] if args.key?(:machine_type_series) @metadata = args[:metadata] if args.key?(:metadata) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @network_tags = args[:network_tags] if args.key?(:network_tags) @secure_boot = args[:secure_boot] if args.key?(:secure_boot) @service_account = args[:service_account] if args.key?(:service_account) @vm_name = args[:vm_name] if args.key?(:vm_name) end |