Class: Google::Apis::VmmigrationV1alpha1::ImageImport
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1alpha1::ImageImport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb
Overview
ImageImport describes the configuration of the image import to run.
Instance Attribute Summary collapse
-
#cloud_storage_uri ⇒ String
Immutable.
-
#create_time ⇒ String
Output only.
-
#disk_image_target_defaults ⇒ Google::Apis::VmmigrationV1alpha1::DiskImageTargetDetails
The target details of the image resource that will be created by the import job.
-
#encryption ⇒ Google::Apis::VmmigrationV1alpha1::Encryption
Encryption message describes the details of the applied encryption.
-
#machine_image_target_defaults ⇒ Google::Apis::VmmigrationV1alpha1::MachineImageTargetDetails
The target details of the machine image resource that will be created by the image import job.
-
#name ⇒ String
Output only.
-
#recent_image_import_jobs ⇒ Array<Google::Apis::VmmigrationV1alpha1::ImageImportJob>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageImport
constructor
A new instance of ImageImport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageImport
Returns a new instance of ImageImport.
2751 2752 2753 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_storage_uri ⇒ String
Immutable. The path to the Cloud Storage file from which the image should be
imported.
Corresponds to the JSON property cloudStorageUri
2716 2717 2718 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2716 def cloud_storage_uri @cloud_storage_uri end |
#create_time ⇒ String
Output only. The time the image import was created.
Corresponds to the JSON property createTime
2721 2722 2723 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2721 def create_time @create_time end |
#disk_image_target_defaults ⇒ Google::Apis::VmmigrationV1alpha1::DiskImageTargetDetails
The target details of the image resource that will be created by the import
job.
Corresponds to the JSON property diskImageTargetDefaults
2727 2728 2729 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2727 def disk_image_target_defaults @disk_image_target_defaults end |
#encryption ⇒ Google::Apis::VmmigrationV1alpha1::Encryption
Encryption message describes the details of the applied encryption.
Corresponds to the JSON property encryption
2732 2733 2734 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2732 def encryption @encryption end |
#machine_image_target_defaults ⇒ Google::Apis::VmmigrationV1alpha1::MachineImageTargetDetails
The target details of the machine image resource that will be created by the
image import job.
Corresponds to the JSON property machineImageTargetDefaults
2738 2739 2740 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2738 def machine_image_target_defaults @machine_image_target_defaults end |
#name ⇒ String
Output only. The resource path of the ImageImport.
Corresponds to the JSON property name
2743 2744 2745 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2743 def name @name end |
#recent_image_import_jobs ⇒ Array<Google::Apis::VmmigrationV1alpha1::ImageImportJob>
Output only. The result of the most recent runs for this ImageImport. All jobs
for this ImageImport can be listed via ListImageImportJobs.
Corresponds to the JSON property recentImageImportJobs
2749 2750 2751 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2749 def recent_image_import_jobs @recent_image_import_jobs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2756 2757 2758 2759 2760 2761 2762 2763 2764 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 2756 def update!(**args) @cloud_storage_uri = args[:cloud_storage_uri] if args.key?(:cloud_storage_uri) @create_time = args[:create_time] if args.key?(:create_time) @disk_image_target_defaults = args[:disk_image_target_defaults] if args.key?(:disk_image_target_defaults) @encryption = args[:encryption] if args.key?(:encryption) @machine_image_target_defaults = args[:machine_image_target_defaults] if args.key?(:machine_image_target_defaults) @name = args[:name] if args.key?(:name) @recent_image_import_jobs = args[:recent_image_import_jobs] if args.key?(:recent_image_import_jobs) end |