Class: Google::Apis::VmmigrationV1alpha1::MigrationError
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1alpha1::MigrationError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb
Overview
Represents migration resource error information that can be used with google. rpc.Status message. MigrationError is used to present the user with error information in migration operations.
Instance Attribute Summary collapse
-
#action_item ⇒ Google::Apis::VmmigrationV1alpha1::LocalizedMessage
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
-
#code ⇒ String
Output only.
-
#error_message ⇒ Google::Apis::VmmigrationV1alpha1::LocalizedMessage
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
-
#error_time ⇒ String
Output only.
-
#help_links ⇒ Array<Google::Apis::VmmigrationV1alpha1::Link>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrationError
constructor
A new instance of MigrationError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrationError
Returns a new instance of MigrationError.
3895 3896 3897 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_item ⇒ Google::Apis::VmmigrationV1alpha1::LocalizedMessage
Provides a localized error message that is safe to return to the user which
can be attached to an RPC error.
Corresponds to the JSON property actionItem
3871 3872 3873 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3871 def action_item @action_item end |
#code ⇒ String
Output only. The error code.
Corresponds to the JSON property code
3876 3877 3878 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3876 def code @code end |
#error_message ⇒ Google::Apis::VmmigrationV1alpha1::LocalizedMessage
Provides a localized error message that is safe to return to the user which
can be attached to an RPC error.
Corresponds to the JSON property errorMessage
3882 3883 3884 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3882 def @error_message end |
#error_time ⇒ String
Output only. The time the error occurred.
Corresponds to the JSON property errorTime
3887 3888 3889 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3887 def error_time @error_time end |
#help_links ⇒ Array<Google::Apis::VmmigrationV1alpha1::Link>
Output only. URL(s) pointing to additional information on handling the current
error.
Corresponds to the JSON property helpLinks
3893 3894 3895 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3893 def help_links @help_links end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3900 3901 3902 3903 3904 3905 3906 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3900 def update!(**args) @action_item = args[:action_item] if args.key?(:action_item) @code = args[:code] if args.key?(:code) @error_message = args[:error_message] if args.key?(:error_message) @error_time = args[:error_time] if args.key?(:error_time) @help_links = args[:help_links] if args.key?(:help_links) end |