Class: Google::Apis::VmmigrationV1alpha1::MigrationWarning
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1alpha1::MigrationWarning
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb
Overview
Represents migration resource warning information that can be used with google. rpc.Status message. MigrationWarning is used to present the user with warning information in migration operations.
Instance Attribute Summary collapse
-
#action_item ⇒ Google::Apis::VmmigrationV1alpha1::LocalizedMessage
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
-
#code ⇒ String
The warning code.
-
#help_links ⇒ Array<Google::Apis::VmmigrationV1alpha1::Link>
Output only.
-
#warning_message ⇒ Google::Apis::VmmigrationV1alpha1::LocalizedMessage
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
-
#warning_time ⇒ String
The time the warning occurred.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrationWarning
constructor
A new instance of MigrationWarning.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrationWarning
Returns a new instance of MigrationWarning.
3937 3938 3939 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_item ⇒ Google::Apis::VmmigrationV1alpha1::LocalizedMessage
Provides a localized error message that is safe to return to the user which
can be attached to an RPC error.
Corresponds to the JSON property actionItem
3913 3914 3915 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3913 def action_item @action_item end |
#code ⇒ String
The warning code.
Corresponds to the JSON property code
3918 3919 3920 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3918 def code @code end |
#help_links ⇒ Array<Google::Apis::VmmigrationV1alpha1::Link>
Output only. URL(s) pointing to additional information on handling the current
warning.
Corresponds to the JSON property helpLinks
3924 3925 3926 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3924 def help_links @help_links end |
#warning_message ⇒ Google::Apis::VmmigrationV1alpha1::LocalizedMessage
Provides a localized error message that is safe to return to the user which
can be attached to an RPC error.
Corresponds to the JSON property warningMessage
3930 3931 3932 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3930 def @warning_message end |
#warning_time ⇒ String
The time the warning occurred.
Corresponds to the JSON property warningTime
3935 3936 3937 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3935 def warning_time @warning_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 3942 def update!(**args) @action_item = args[:action_item] if args.key?(:action_item) @code = args[:code] if args.key?(:code) @help_links = args[:help_links] if args.key?(:help_links) @warning_message = args[:warning_message] if args.key?(:warning_message) @warning_time = args[:warning_time] if args.key?(:warning_time) end |