Class: Google::Apis::VmmigrationV1alpha1::ShieldedInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1alpha1::ShieldedInstanceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb
Overview
Shielded instance configuration.
Instance Attribute Summary collapse
-
#enable_integrity_monitoring ⇒ Boolean
(also: #enable_integrity_monitoring?)
Optional.
-
#enable_vtpm ⇒ Boolean
(also: #enable_vtpm?)
Optional.
-
#secure_boot ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShieldedInstanceConfig
constructor
A new instance of ShieldedInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShieldedInstanceConfig
Returns a new instance of ShieldedInstanceConfig.
4617 4618 4619 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_integrity_monitoring ⇒ Boolean Also known as: enable_integrity_monitoring?
Optional. Defines whether the instance created by the machine image has
integrity monitoring enabled. This can be set to true only if the image boot
option is EFI, and vTPM is enabled.
Corresponds to the JSON property enableIntegrityMonitoring
4601 4602 4603 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4601 def enable_integrity_monitoring @enable_integrity_monitoring end |
#enable_vtpm ⇒ Boolean Also known as: enable_vtpm?
Optional. Defines whether the instance created by the machine image has vTPM
enabled. This can be set to true only if the image boot option is EFI.
Corresponds to the JSON property enableVtpm
4608 4609 4610 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4608 def enable_vtpm @enable_vtpm end |
#secure_boot ⇒ String
Optional. Defines whether the instance created by the machine image has Secure
Boot enabled. This can be set to true only if the image boot option is EFI.
Corresponds to the JSON property secureBoot
4615 4616 4617 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4615 def secure_boot @secure_boot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4622 4623 4624 4625 4626 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 4622 def update!(**args) @enable_integrity_monitoring = args[:enable_integrity_monitoring] if args.key?(:enable_integrity_monitoring) @enable_vtpm = args[:enable_vtpm] if args.key?(:enable_vtpm) @secure_boot = args[:secure_boot] if args.key?(:secure_boot) end |