Class: Google::Apis::VmmigrationV1alpha1::UpgradeStatus
- Inherits:
-
Object
- Object
- Google::Apis::VmmigrationV1alpha1::UpgradeStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb
Overview
UpgradeStatus contains information about upgradeAppliance operation.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::VmmigrationV1alpha1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#previous_version ⇒ String
The version from which we upgraded.
-
#start_time ⇒ String
The time the operation was started.
-
#state ⇒ String
The state of the upgradeAppliance operation.
-
#version ⇒ String
The version to upgrade to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeStatus
constructor
A new instance of UpgradeStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeStatus
Returns a new instance of UpgradeStatus.
5086 5087 5088 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5086 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::VmmigrationV1alpha1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
5064 5065 5066 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5064 def error @error end |
#previous_version ⇒ String
The version from which we upgraded.
Corresponds to the JSON property previousVersion
5069 5070 5071 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5069 def previous_version @previous_version end |
#start_time ⇒ String
The time the operation was started.
Corresponds to the JSON property startTime
5074 5075 5076 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5074 def start_time @start_time end |
#state ⇒ String
The state of the upgradeAppliance operation.
Corresponds to the JSON property state
5079 5080 5081 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5079 def state @state end |
#version ⇒ String
The version to upgrade to.
Corresponds to the JSON property version
5084 5085 5086 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5084 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5091 5092 5093 5094 5095 5096 5097 |
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5091 def update!(**args) @error = args[:error] if args.key?(:error) @previous_version = args[:previous_version] if args.key?(:previous_version) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @version = args[:version] if args.key?(:version) end |