Class: Google::Apis::VmmigrationV1alpha1::UpgradeStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vmmigration_v1alpha1/classes.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb,
lib/google/apis/vmmigration_v1alpha1/representations.rb

Overview

UpgradeStatus contains information about upgradeAppliance operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeStatus

Returns a new instance of UpgradeStatus.



5080
5081
5082
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::VmmigrationV1alpha1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



5058
5059
5060
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5058

def error
  @error
end

#previous_versionString

The version from which we upgraded. Corresponds to the JSON property previousVersion

Returns:

  • (String)


5063
5064
5065
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5063

def previous_version
  @previous_version
end

#start_timeString

The time the operation was started. Corresponds to the JSON property startTime

Returns:

  • (String)


5068
5069
5070
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5068

def start_time
  @start_time
end

#stateString

The state of the upgradeAppliance operation. Corresponds to the JSON property state

Returns:

  • (String)


5073
5074
5075
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5073

def state
  @state
end

#versionString

The version to upgrade to. Corresponds to the JSON property version

Returns:

  • (String)


5078
5079
5080
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5078

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5085
5086
5087
5088
5089
5090
5091
# File 'lib/google/apis/vmmigration_v1alpha1/classes.rb', line 5085

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @previous_version = args[:previous_version] if args.key?(:previous_version)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
end